@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12853 2021-04-22 07:31:24Z Lavender $
+# $Id: __init__.py 12870 2021-04-29 11:05:43Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2021-04-22 15:31:24 +0800 (週四, 22 四月 2021) $
-# $Revision: 12853 $
+# $Date: 2021-04-29 19:05:43 +0800 (週四, 29 四月 2021) $
+# $Revision: 12870 $
 
 from __future__ import print_function
 
@@ -1041,7 +1041,7 @@ def attachDebugURLs(settings, urlpatterns):
                 url(r'^__debug__/', include(debug_toolbar.urls)),
             )
 
-def attachURLs(settings, urlpatterns, excludeApps=[]):
+def attachURLs(settings, urlpatterns, excludeApps=()):
     """
     Attach patched (for example, debug and admin...etc.) urlpatterns.
     It must be called in urls.py by passing urlpatterns.
