@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12834 2021-04-08 03:24:09Z Casey $
+# $Id: __init__.py 12940 2021-06-03 15:19:56Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $ (last)
-# $Date: 2021-04-08 11:24:09 +0800 (週四, 08 四月 2021) $
-# $Revision: 12834 $
+# $Author: Lavender $ (last)
+# $Date: 2021-06-03 23:19:56 +0800 (週四, 03 六月 2021) $
+# $Revision: 12940 $
 
 import os
 import sys
@@ -227,6 +227,23 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         https = os.environ.get('HTTPS', None)
         if https == 'on':
             settingsDict['DEFAULT_HTTP_PROTOCOL'] = 'https'
+            
+    #=========================================================================
+    if getattr(settingsDict, "IUNO_MEMBER_TRAC_ENABLE", True):
+        # trac login
+        tracDefaults = {
+            'DEFAULT_TRAC_AUTH_URL': 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625',
+            'DEFAULT_TRAC_AUTH_USERNAME': 'Deploy',
+            'DEFAULT_TRAC_AUTH_PASSWORD': 'ei0W1aUeP1pcRvJoV4X8ZC2xm',
+            "SET_TRAC_LOGIN_AS_STAFF": False,
+            "SET_TRAC_LOGIN_AS_SUPERUSER": False,
+        }
+        
+        settingsDict["AUTHENTICATION_BACKENDS"] = [
+            'Iuno.member.Backends.TracBackend',
+        ]
+
+        update(settingsDict, tracDefaults)
 
 def attachURLs(settings, urlpatterns):
     from django.conf.urls import include, url
